Documentation
¶
Index ¶
- func Fzf(in bytes.Buffer) (string, error)
- func FzfListContexts() (string, error)
- func FzfListKubeconfigs(c *Cfg) (string, error)
- func RemoveContextFromKubeConfig(context string, kubeconfig *api.Config) (*api.Config, error)
- func RemoveOrphanedClustersFromKubeConfig(kubeconfig *api.Config) ([]string, error)
- func RemoveOrphanedUsersFromKubeConfig(kubeconfig *api.Config) ([]string, error)
- type Cfg
- type Item
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Fzf ¶
Fzf uses fzf to display a fuzzy finder in stdout. Returns a string containing the selected item in the fzf result
func FzfListContexts ¶
func FzfListKubeconfigs ¶
func RemoveContextFromKubeConfig ¶
Remove a context from provided kubeconfig, including it's referenced user and context
func RemoveOrphanedClustersFromKubeConfig ¶
Remove orphaned clusters from provided kubeconfig
Types ¶
Click to show internal directories.
Click to hide internal directories.